@@ -478,7 +478,7 @@ def dump_primary(primary):
 
         res += '  <format>\n'
 
-        res += '    <rpm:license>%s</rpm:license>\n' % fmt['license']
+        res += '    <rpm:license>%s</rpm:license>\n' % escape(fmt['license'])
 
         if fmt['vendor']:
             res += '    <rpm:vendor>%s</rpm:vendor>\n' % escape(fmt['vendor'])
@@ -516,7 +516,7 @@ def dump_primary(primary):
                 if provides[component] is not None:
                     entry.append('%s="%s"' % (component, provides[component]))
 
-            res += '      <rpm:entry ' + ' '.join(entry) + '/>\n'
+            res += '      <rpm:entry ' + escape(' '.join(entry)) + '/>\n'
 
         res += '    </rpm:provides>\n'
 
@@ -529,7 +529,7 @@ def dump_primary(primary):
                 if requires[component] is not None:
                     entry.append('%s="%s"' % (component, requires[component]))
 
-            res += '      <rpm:entry ' + ' '.join(entry) + '/>\n'
+            res += '      <rpm:entry ' + escape(' '.join(entry)) + '/>\n'
 
         res += '    </rpm:requires>\n'
 
@@ -542,7 +542,7 @@ def dump_primary(primary):
                 if obsoletes[component] is not None:
                     entry.append('%s="%s"' % (component, obsoletes[component]))
 
-            res += '      <rpm:entry ' + ' '.join(entry) + '/>\n'
+            res += '      <rpm:entry ' + escape(' '.join(entry)) + '/>\n'
 
         res += '    </rpm:obsoletes>\n'
 
